==> haskell-htf-0.15.0.0-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HTF
version:              0.15.0.0
visibility:           public
id:                   HTF-0.15.0.0-9d2eTYtGhB9HoRr6dshY8L
key:                  HTF-0.15.0.0-9d2eTYtGhB9HoRr6dshY8L
license:              LGPL-2.1-only
copyright:            (c) 2005-2015 Stefan Wehr
maintainer:           Stefan Wehr <wehr@factisresearch.com>
author:               Stefan Wehr <wehr@factisresearch.com>
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  43f3feabfbfe776788ce68c0aed723be
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/HTF-0.15.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/HTF-0.15.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.0-9d2eTYtGhB9HoRr6dshY8L
depends:
    Diff-0.4.1-3IsIUDIZJcI44RzSs8EsNR
    HUnit-1.6.2.0-C1iPOmv2pdMIa65hP6dNHl
    QuickCheck-2.14.2-6E1s0nkrQNJIUaQam68i9u
    aeson-1.5.6.0-ByG4maisB6W4LqbYiVYaDZ array-0.5.4.0 base-4.15.1.0
    base64-bytestring-1.2.1.0-KbN6G8Oab0JGXDIOSmHWBi
    bytestring-0.10.12.1 containers-0.6.4.1
    cpphs-1.20.9.1-1jAFiSyqcHj3RbgQIQP02q directory-1.3.6.2
    haskell-src-1.0.4-I0vDsuqcD0W8qqsasfiG55
    lifted-base-0.2.3.12-HATOF6YECeF3LkXsP92li
    monad-control-1.0.3.1-GF3sqD95P1QIutZdI2Mbz7 mtl-2.2.2
    old-time-1.1.0.3-B4Ro2AUl5kn1VzPHPQkaoe pretty-1.1.3.6
    process-1.6.13.2 random-1.2.1.1-8Yy442tDgI9KXa8FjBISNx
    regex-compat-0.95.2.1-itFB4fXPjn9OuocZGgbix text-1.2.5.0 time-1.9.3
    unix-2.7.2.2 vector-0.12.3.1-6Jse5cnDdy2CJPq6wEcUm1
    xmlgen-0.6.2.2-2JcVfWF3aE6EQ9r8vtMvKL

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-htf-0.15.0.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-htf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HTF
version:              0.15.0.0
visibility:           public
id:                   HTF-0.15.0.0-759fos1P80G705EHCpN5nD
key:                  HTF-0.15.0.0-759fos1P80G705EHCpN5nD
license:              LGPL-2.1-only
copyright:            (c) 2005-2015 Stefan Wehr
maintainer:           Stefan Wehr <wehr@factisresearch.com>
author:               Stefan Wehr <wehr@factisresearch.com>
stability:            Beta
homepage:             https://github.com/skogsbaer/HTF/
synopsis:             The Haskell Test Framework
description:
    The Haskell Test Framework (/HTF/ for short) lets you define and organize unit tests,
    QuickCheck properties,
    and black box tests in an
    easy and convenient way. HTF uses a custom preprocessor that collects
    test definitions automatically.

    HTF produces highly readable output
    for failing test cases: it provides exact file name and line number
    information,
    it colors and pretty prints expected and
    actual results, and it displays a diff highlighting the mismatching parts.

    The documentation of the "Test.Framework.Tutorial" module
    provides a tutorial for HTF. The /sample/ provides a good starting point for
    a project using HTF.

category:             Testing
abi:                  3a93ace7c390ae012980b641a6e9fd2c
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.AssertM Test.Framework.BlackBoxTest
    Test.Framework.HUnitWrapper Test.Framework.History
    Test.Framework.JsonOutput Test.Framework.Location
    Test.Framework.Preprocessor Test.Framework.Pretty
    Test.Framework.PrettyHaskell Test.Framework.QuickCheckWrapper
    Test.Framework.TestInterface Test.Framework.TestManager
    Test.Framework.TestTypes Test.Framework.ThreadPool
    Test.Framework.Tutorial Test.Framework.XmlOutput

hidden-modules:
    Paths_HTF Test.Framework.CmdlineOptions Test.Framework.Colors
    Test.Framework.Diff Test.Framework.Process
    Test.Framework.TestReporter Test.Framework.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/HTF-0.15.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/HTF-0.15.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-htf
hs-libraries:         HSHTF-0.15.0.0-759fos1P80G705EHCpN5nD
depends:
    Diff-0.4.1-nBJKDluwWQdBlfGBrAAN
    HUnit-1.6.2.0-C1iPOmv2pdMIa65hP6dNHl
    QuickCheck-2.14.2-GLQMRdYhd1gGRweU1OeGdf
    aeson-1.5.6.0-8RmaUxpnEyzFEsjlzg3EtT array-0.5.4.0 base-4.15.1.0
    base64-bytestring-1.2.1.0-1fkEAiWil2K1dOnXMNj6lY
    bytestring-0.10.12.1 containers-0.6.4.1
    cpphs-1.20.9.1-1jAFiSyqcHj3RbgQIQP02q directory-1.3.6.2
    haskell-src-1.0.4-EG9sVpFWgCc5oQXbDMXyCQ
    lifted-base-0.2.3.12-1TuuQhpd15S3w9qEsQ0mYH
    monad-control-1.0.3.1-Fcjv9SGMt3s3K9SeXZ6blX mtl-2.2.2
    old-time-1.1.0.3-B4Ro2AUl5kn1VzPHPQkaoe pretty-1.1.3.6
    process-1.6.13.2 random-1.2.1.1-7TRcTZqox1I8Tbxmbf4Iv1
    regex-compat-0.95.2.1-itFB4fXPjn9OuocZGgbix text-1.2.5.0 time-1.9.3
    unix-2.7.2.2 vector-0.12.3.1-Ez332dT0qjy6X3Ga8WsjkB
    xmlgen-0.6.2.2-EEdYzs3GcQIFTrygbfBmr0

haddock-interfaces:   /usr/share/doc/haskell-htf/html/HTF.haddock
haddock-html:         /usr/share/doc/haskell-htf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
